==> compliance-trestle-0.7.2.tar.gz: compliance-trestle-0.7.2/.github/PULL_REQUEST_TEMPLATE.md <==
## Types of changes

<!--- What types of changes does your code introduce? Put an `x` in all the boxes that apply: -->

- \[ \] Bug fix (non-breaking change which fixes an issue)
- \[ \] New feature (non-breaking change which adds functionality)
- \[ \] Breaking change (fix or feature that would cause existing functionality to change)
- \[ \] My code follows the code style of this project.
- \[ \] My change requires a change to the documentation.
- \[ \] I have updated the documentation accordingly.
- \[ \] I have added tests to cover my changes.
- \[ \] All new and existing tests passed.
- \[ \] All commits are signed-off.

<!---
## Pull requests instructions

Please, go through these steps before you submit a PR.

1. Make sure that your PR is not a duplicate.

1. If not, then make sure that:

   a. You have done your changes in a separate branch. Branches MUST have descriptive names that start with either the `fix/` or `feature/` prefixes. Good examples are: `fix/signin-issue` or `feature/issue-templates`.

   b. You have a descriptive commit message with a short title (first line).

   c. Please make sure that your branch passes tests before

1. **After** these steps, you're ready to open a pull request.

   a. Your pull request MUST NOT target the `main` branch on this repository. You probably want to target `develop` instead.

   b. Give a descriptive title to your PR.

   c. Provide a description of your changes.

   d. Put `closes #XXXX` in your comment to auto-close the issue that your PR fixes (if such).

   e Link all other issues which the PR refers to if not closing an issue. At least one issue MUST be linked or close for a PR to be accepted.

-->

==> compliance-trestle-0.23.0.tar.gz: compliance-trestle-0.23.0/.github/PULL_REQUEST_TEMPLATE.md <==
## Types of changes

<!--- What types of changes does your code introduce? Put an `x` in all the boxes that apply: -->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] My code follows the code style of this project.
- [ ] My change requires a change to the documentation.
- [ ] I have updated the documentation accordingly.
- [ ] I have added tests to cover my changes.
- [ ] All new and existing tests passed.
- [ ] All commits are signed-off.

<!---
## Pull requests instructions

Please, go through these steps before you submit a PR.

1. Make sure that your PR is not a duplicate.

1. If not, then make sure that:

   a. You have done your changes in a separate branch. Branches MUST have descriptive names that start with either the `fix/` or `feature/` prefixes. Good examples are: `fix/signin-issue` or `feature/issue-templates`.

   b. You have a descriptive commit message with a short title (first line).

   c. Please make sure that your branch passes tests before

1. **After** these steps, you're ready to open a pull request.

   a. Your pull request MUST NOT target the `main` branch on this repository. You probably want to target `develop` instead.

   b. Give a descriptive title to your PR.

   c. Provide a description of your changes.

   d. Put `closes #XXXX` in your comment to auto-close the issue that your PR fixes (if such).

   e Link all other issues which the PR refers to if not closing an issue. At least one issue MUST be linked or close for a PR to be accepted.

-->
